==> odata-client-msgraph-beta-0.1.26-sources.jar: odata/msgraph/client/beta/complex/CredentialSingleSignOnExtension.java <==
package odata.msgraph.client.beta.complex;

import com.fasterxml.jackson.annotation.JacksonInject;
import com.fasterxml.jackson.annotation.JsonAnySetter;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonInclude.Include;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.github.davidmoten.odata.client.CollectionPage;
import com.github.davidmoten.odata.client.HttpRequestOptions;
import com.github.davidmoten.odata.client.ODataType;
import com.github.davidmoten.odata.client.Util;
import com.github.davidmoten.odata.client.annotation.Property;
import com.github.davidmoten.odata.client.internal.ChangedFields;
import com.github.davidmoten.odata.client.internal.EdmSchemaInfo;
import com.github.davidmoten.odata.client.internal.UnmappedFields;

import java.util.Arrays;
import java.util.Collections;
import java.util.List;
import java.util.Optional;

import odata.msgraph.client.beta.schema.SchemaInfo;


/**
 * <i>“Represents a Credential-type Single Sign-On extension profile.”</i>
 */@JsonPropertyOrder({
    "@odata.type", 
    "extensionIdentifier", 
    "teamIdentifier", 
    "domains", 
    "realm", 
    "configurations"})
@JsonInclude(Include.NON_NULL)
public class CredentialSingleSignOnExtension extends SingleSignOnExtension implements ODataType {

    @JacksonInject
    @JsonIgnore
    protected UnmappedFields unmappedFields;

    @JsonProperty("extensionIdentifier")
    protected String extensionIdentifier;

    @JsonProperty("teamIdentifier")
    protected String teamIdentifier;

    @JsonProperty("domains")
    protected List<String> domains;

    @JsonProperty("domains@nextLink")
    protected String domainsNextLink;

    @JsonProperty("realm")
    protected String realm;

    @JsonProperty("configurations")
    protected List<KeyTypedValuePair> configurations;

    @JsonProperty("configurations@nextLink")
    protected String configurationsNextLink;

    protected CredentialSingleSignOnExtension() {
        super();
    }

    @Override
    public String odataTypeName() {
        return "microsoft.graph.credentialSingleSignOnExtension";
    }

    /**
     * <i>“Gets or sets the bundle ID of the app extension that performs SSO for the
     * specified URLs.”</i>
     * 
     * @return property extensionIdentifier
     */
    @Property(name="extensionIdentifier")
    @JsonIgnore
    public Optional<String> getExtensionIdentifier() {
        return Optional.ofNullable(extensionIdentifier);
    }

    /**
     * Returns an immutable copy of {@code this} with just the {@code
     * extensionIdentifier} field changed. Field description below. The field name is
     * also added to an internal map of changed fields in the returned object so that
     * when {@code this.patch()} is called (if available)on the returned object only
     * the changed fields are submitted.
     * <p>
     * <i>“Gets or sets the bundle ID of the app extension that performs SSO for the
     * specified URLs.”</i>
     * 
     * @param extensionIdentifier
     *            new value of {@code extensionIdentifier} field (as defined in service metadata)
     * @return immutable copy of {@code this} with just the {@code extensionIdentifier} field changed
     */
    public CredentialSingleSignOnExtension withExtensionIdentifier(String extensionIdentifier) {
        CredentialSingleSignOnExtension _x = _copy();
        _x.odataType = Util.nvl(odataType, "microsoft.graph.credentialSingleSignOnExtension");
        _x.extensionIdentifier = extensionIdentifier;
        return _x;
    }

    /**
     * <i>“Gets or sets the team ID of the app extension that performs SSO for the
     * specified URLs.”</i>
     * 
     * @return property teamIdentifier
     */
    @Property(name="teamIdentifier")
    @JsonIgnore
    public Optional<String> getTeamIdentifier() {
        return Optional.ofNullable(teamIdentifier);
    }

    /**
     * Returns an immutable copy of {@code this} with just the {@code teamIdentifier}
     * field changed. Field description below. The field name is also added to an
     * internal map of changed fields in the returned object so that when {@code this.
     * patch()} is called (if available)on the returned object only the changed fields
     * are submitted.
     * <p>
     * <i>“Gets or sets the team ID of the app extension that performs SSO for the
     * specified URLs.”</i>
     * 
     * @param teamIdentifier
     *            new value of {@code teamIdentifier} field (as defined in service metadata)
     * @return immutable copy of {@code this} with just the {@code teamIdentifier} field changed
     */
    public CredentialSingleSignOnExtension withTeamIdentifier(String teamIdentifier) {
        CredentialSingleSignOnExtension _x = _copy();
        _x.odataType = Util.nvl(odataType, "microsoft.graph.credentialSingleSignOnExtension");
        _x.teamIdentifier = teamIdentifier;
        return _x;
    }

    /**
     * <i>“Gets or sets a list of hosts or domain names for which the app extension
     * performs SSO.”</i>
     * 
     * @return property domains
     */
    @Property(name="domains")
    @JsonIgnore
    public CollectionPage<String> getDomains() {
        return new CollectionPage<String>(contextPath, String.class, domains, Optional.ofNullable(domainsNextLink), EdmSchemaInfo.INSTANCE, Collections.emptyList(), HttpRequestOptions.EMPTY);
    }

    /**
     * <i>“Gets or sets a list of hosts or domain names for which the app extension
     * performs SSO.”</i>
     * 
     * @return property domains
     */
    @Property(name="domains")
    @JsonIgnore
    public CollectionPage<String> getDomains(HttpRequestOptions options) {
        return new CollectionPage<String>(contextPath, String.class, domains, Optional.ofNullable(domainsNextLink), EdmSchemaInfo.INSTANCE, Collections.emptyList(), options);
    }

    /**
     * <i>“Gets or sets the case-sensitive realm name for this profile.”</i>
     * 
     * @return property realm
     */
    @Property(name="realm")
    @JsonIgnore
    public Optional<String> getRealm() {
        return Optional.ofNullable(realm);
    }

    /**
     * Returns an immutable copy of {@code this} with just the {@code realm} field
     * changed. Field description below. The field name is also added to an internal
     * map of changed fields in the returned object so that when {@code this.patch()}
     * is called (if available)on the returned object only the changed fields are
     * submitted.
     * <p>
     * <i>“Gets or sets the case-sensitive realm name for this profile.”</i>
     * 
     * @param realm
     *            new value of {@code realm} field (as defined in service metadata)
     * @return immutable copy of {@code this} with just the {@code realm} field changed
     */
    public CredentialSingleSignOnExtension withRealm(String realm) {
        CredentialSingleSignOnExtension _x = _copy();
        _x.odataType = Util.nvl(odataType, "microsoft.graph.credentialSingleSignOnExtension");
        _x.realm = realm;
        return _x;
    }

    /**
     * <i>“Gets or sets a list of typed key-value pairs used to configure Credential-type
     * profiles. This collection can contain a maximum of 500 elements.”</i>
     * 
     * @return property configurations
     */
    @Property(name="configurations")
    @JsonIgnore
    public CollectionPage<KeyTypedValuePair> getConfigurations() {
        return new CollectionPage<KeyTypedValuePair>(contextPath, KeyTypedValuePair.class, configurations, Optional.ofNullable(configurationsNextLink), SchemaInfo.INSTANCE, Collections.emptyList(), HttpRequestOptions.EMPTY);
    }

    /**
     * <i>“Gets or sets a list of typed key-value pairs used to configure Credential-type
     * profiles. This collection can contain a maximum of 500 elements.”</i>
     * 
     * @return property configurations
     */
    @Property(name="configurations")
    @JsonIgnore
    public CollectionPage<KeyTypedValuePair> getConfigurations(HttpRequestOptions options) {
        return new CollectionPage<KeyTypedValuePair>(contextPath, KeyTypedValuePair.class, configurations, Optional.ofNullable(configurationsNextLink), SchemaInfo.INSTANCE, Collections.emptyList(), options);
    }

    @JsonAnySetter
    private void setUnmappedField(String name, Object value) {
        if (unmappedFields == null) {
            unmappedFields = new UnmappedFields();
        }
        unmappedFields.put(name, value);
    }

    @Override
    @JsonIgnore
    public UnmappedFields getUnmappedFields() {
        return unmappedFields == null ? new UnmappedFields() : unmappedFields;
    }

    @Override
    public void postInject(boolean addKeysToContextPath) {
        // do nothing;
    }

    /**
     * Returns a builder which is used to create a new
     * instance of this class (given that this class is immutable).
     *
     * @return a new Builder for this class
     */
    // Suffix used on builder factory method to differentiate the method
    // from static builder methods on superclasses
    public static Builder builderCredentialSingleSignOnExtension() {
        return new Builder();
    }

    public static final class Builder {
        private String extensionIdentifier;
        private String teamIdentifier;
        private List<String> domains;
        private String domainsNextLink;
        private String realm;
        private List<KeyTypedValuePair> configurations;
        private String configurationsNextLink;
        private ChangedFields changedFields = new ChangedFields();

        Builder() {
            // prevent instantiation
        }

        /**
         * <i>“Gets or sets the bundle ID of the app extension that performs SSO for the
         * specified URLs.”</i>
         * 
         * @param extensionIdentifier
         *            value of {@code extensionIdentifier} property (as defined in service metadata)
         * @return {@code this} (for method chaining)
         */
        public Builder extensionIdentifier(String extensionIdentifier) {
            this.extensionIdentifier = extensionIdentifier;
            this.changedFields = changedFields.add("extensionIdentifier");
            return this;
        }

        /**
         * <i>“Gets or sets the team ID of the app extension that performs SSO for the
         * specified URLs.”</i>
         * 
         * @param teamIdentifier
         *            value of {@code teamIdentifier} property (as defined in service metadata)
         * @return {@code this} (for method chaining)
         */
        public Builder teamIdentifier(String teamIdentifier) {
            this.teamIdentifier = teamIdentifier;
            this.changedFields = changedFields.add("teamIdentifier");
            return this;
        }

        /**
         * <i>“Gets or sets a list of hosts or domain names for which the app extension
         * performs SSO.”</i>
         * 
         * @param domains
         *            value of {@code domains} property (as defined in service metadata)
         * @return {@code this} (for method chaining)
         */
        public Builder domains(List<String> domains) {
            this.domains = domains;
            this.changedFields = changedFields.add("domains");
            return this;
        }

        /**
         * <i>“Gets or sets a list of hosts or domain names for which the app extension
         * performs SSO.”</i>
         * 
         * @param domains
         *            value of {@code domains} property (as defined in service metadata)
         * @return {@code this} (for method chaining)
         */
        public Builder domains(String... domains) {
            return domains(Arrays.asList(domains));
        }

        /**
         * <i>“Gets or sets a list of hosts or domain names for which the app extension
         * performs SSO.”</i>
         * 
         * @param domainsNextLink
         *            value of {@code domains@nextLink} property (as defined in service metadata)
         * @return {@code this} (for method chaining)
         */
        public Builder domainsNextLink(String domainsNextLink) {
            this.domainsNextLink = domainsNextLink;
            this.changedFields = changedFields.add("domains");
            return this;
        }

        /**
         * <i>“Gets or sets the case-sensitive realm name for this profile.”</i>
         * 
         * @param realm
         *            value of {@code realm} property (as defined in service metadata)
         * @return {@code this} (for method chaining)
         */
        public Builder realm(String realm) {
            this.realm = realm;
            this.changedFields = changedFields.add("realm");
            return this;
        }

        /**
         * <i>“Gets or sets a list of typed key-value pairs used to configure Credential-type
         * profiles. This collection can contain a maximum of 500 elements.”</i>
         * 
         * @param configurations
         *            value of {@code configurations} property (as defined in service metadata)
         * @return {@code this} (for method chaining)
         */
        public Builder configurations(List<KeyTypedValuePair> configurations) {
            this.configurations = configurations;
            this.changedFields = changedFields.add("configurations");
            return this;
        }

        /**
         * <i>“Gets or sets a list of typed key-value pairs used to configure Credential-type
         * profiles. This collection can contain a maximum of 500 elements.”</i>
         * 
         * @param configurations
         *            value of {@code configurations} property (as defined in service metadata)
         * @return {@code this} (for method chaining)
         */
        public Builder configurations(KeyTypedValuePair... configurations) {
            return configurations(Arrays.asList(configurations));
        }

        /**
         * <i>“Gets or sets a list of typed key-value pairs used to configure Credential-type
         * profiles. This collection can contain a maximum of 500 elements.”</i>
         * 
         * @param configurationsNextLink
         *            value of {@code configurations@nextLink} property (as defined in service metadata)
         * @return {@code this} (for method chaining)
         */
        public Builder configurationsNextLink(String configurationsNextLink) {
            this.configurationsNextLink = configurationsNextLink;
            this.changedFields = changedFields.add("configurations");
            return this;
        }

        public CredentialSingleSignOnExtension build() {
            CredentialSingleSignOnExtension _x = new CredentialSingleSignOnExtension();
            _x.contextPath = null;
            _x.unmappedFields = new UnmappedFields();
            _x.odataType = "microsoft.graph.credentialSingleSignOnExtension";
            _x.extensionIdentifier = extensionIdentifier;
            _x.teamIdentifier = teamIdentifier;
            _x.domains = domains;
            _x.domainsNextLink = domainsNextLink;
            _x.realm = realm;
            _x.configurations = configurations;
            _x.configurationsNextLink = configurationsNextLink;
            return _x;
        }
    }

    private CredentialSingleSignOnExtension _copy() {
        CredentialSingleSignOnExtension _x = new CredentialSingleSignOnExtension();
        _x.contextPath = contextPath;
        _x.unmappedFields = unmappedFields;
        _x.odataType = odataType;
        _x.extensionIdentifier = extensionIdentifier;
        _x.teamIdentifier = teamIdentifier;
        _x.domains = domains;
        _x.realm = realm;
        _x.configurations = configurations;
        return _x;
    }

    @Override
    public String toString() {
        StringBuilder b = new StringBuilder();
        b.append("CredentialSingleSignOnExtension[");
        b.append("extensionIdentifier=");
        b.append(this.extensionIdentifier);
        b.append(", ");
        b.append("teamIdentifier=");
        b.append(this.teamIdentifier);
        b.append(", ");
        b.append("domains=");
        b.append(this.domains);
        b.append(", ");
        b.append("realm=");
        b.append(this.realm);
        b.append(", ");
        b.append("configurations=");
        b.append(this.configurations);
        b.append("]");
        b.append(",unmappedFields=");
        b.append(unmappedFields);
        b.append(",odataType=");
        b.append(odataType);
        return b.toString();
    }

}

==> odata-client-msgraph-beta-0.2.2-sources.jar: odata/msgraph/client/beta/complex/CredentialSingleSignOnExtension.java <==
package odata.msgraph.client.beta.complex;

import com.fasterxml.jackson.annotation.JsonAnyGetter;
import com.fasterxml.jackson.annotation.JsonAnySetter;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonInclude.Include;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.github.davidmoten.odata.client.CollectionPage;
import com.github.davidmoten.odata.client.HttpRequestOptions;
import com.github.davidmoten.odata.client.ODataType;
import com.github.davidmoten.odata.client.UnmappedFields;
import com.github.davidmoten.odata.client.Util;
import com.github.davidmoten.odata.client.annotation.Property;
import com.github.davidmoten.odata.client.internal.ChangedFields;
import com.github.davidmoten.odata.client.internal.UnmappedFieldsImpl;

import java.lang.Object;
import java.lang.Override;
import java.lang.String;
import java.lang.StringBuilder;
import java.util.Arrays;
import java.util.Collections;
import java.util.List;
import java.util.Optional;


/**
 * <i>“Represents a Credential-type Single Sign-On extension profile.”</i>
 */@JsonPropertyOrder({
    "@odata.type", 
    "configurations", 
    "domains", 
    "extensionIdentifier", 
    "realm", 
    "teamIdentifier"})
@JsonInclude(Include.NON_NULL)
public class CredentialSingleSignOnExtension extends SingleSignOnExtension implements ODataType {

    @JsonProperty("configurations")
    protected List<KeyTypedValuePair> configurations;

    @JsonProperty("configurations@nextLink")
    protected String configurationsNextLink;

    @JsonProperty("domains")
    protected List<String> domains;

    @JsonProperty("domains@nextLink")
    protected String domainsNextLink;

    @JsonProperty("extensionIdentifier")
    protected String extensionIdentifier;

    @JsonProperty("realm")
    protected String realm;

    @JsonProperty("teamIdentifier")
    protected String teamIdentifier;

    protected CredentialSingleSignOnExtension() {
        super();
    }

    @Override
    public String odataTypeName() {
        return "microsoft.graph.credentialSingleSignOnExtension";
    }

    /**
     * <i>“Gets or sets a list of typed key-value pairs used to configure Credential-type
     * profiles. This collection can contain a maximum of 500 elements.”</i>
     * 
     * @return property configurations
     */
    @Property(name="configurations")
    @JsonIgnore
    public CollectionPage<KeyTypedValuePair> getConfigurations() {
        return new CollectionPage<KeyTypedValuePair>(contextPath, KeyTypedValuePair.class, this.configurations, Optional.ofNullable(configurationsNextLink), Collections.emptyList(), HttpRequestOptions.EMPTY);
    }

    /**
     * <i>“Gets or sets a list of typed key-value pairs used to configure Credential-type
     * profiles. This collection can contain a maximum of 500 elements.”</i>
     * 
     * @param options
     *            specify connect and read timeouts
     * @return property configurations
     */
    @Property(name="configurations")
    @JsonIgnore
    public CollectionPage<KeyTypedValuePair> getConfigurations(HttpRequestOptions options) {
        return new CollectionPage<KeyTypedValuePair>(contextPath, KeyTypedValuePair.class, this.configurations, Optional.ofNullable(configurationsNextLink), Collections.emptyList(), options);
    }

    /**
     * <i>“Gets or sets a list of hosts or domain names for which the app extension
     * performs SSO.”</i>
     * 
     * @return property domains
     */
    @Property(name="domains")
    @JsonIgnore
    public CollectionPage<String> getDomains() {
        return new CollectionPage<String>(contextPath, String.class, this.domains, Optional.ofNullable(domainsNextLink), Collections.emptyList(), HttpRequestOptions.EMPTY);
    }

    /**
     * <i>“Gets or sets a list of hosts or domain names for which the app extension
     * performs SSO.”</i>
     * 
     * @param options
     *            specify connect and read timeouts
     * @return property domains
     */
    @Property(name="domains")
    @JsonIgnore
    public CollectionPage<String> getDomains(HttpRequestOptions options) {
        return new CollectionPage<String>(contextPath, String.class, this.domains, Optional.ofNullable(domainsNextLink), Collections.emptyList(), options);
    }

    /**
     * <i>“Gets or sets the bundle ID of the app extension that performs SSO for the
     * specified URLs.”</i>
     * 
     * @return property extensionIdentifier
     */
    @Property(name="extensionIdentifier")
    @JsonIgnore
    public Optional<String> getExtensionIdentifier() {
        return Optional.ofNullable(extensionIdentifier);
    }

    /**
     * Returns an immutable copy of {@code this} with just the {@code
     * extensionIdentifier} field changed. Field description below. The field name is
     * also added to an internal map of changed fields in the returned object so that
     * when {@code this.patch()} is called (if available)on the returned object only
     * the changed fields are submitted.
     * <p>
     * <i>“Gets or sets the bundle ID of the app extension that performs SSO for the
     * specified URLs.”</i>
     * 
     * @param extensionIdentifier
     *            new value of {@code extensionIdentifier} field (as defined in service metadata)
     * @return immutable copy of {@code this} with just the {@code extensionIdentifier} field changed
     */
    public CredentialSingleSignOnExtension withExtensionIdentifier(String extensionIdentifier) {
        CredentialSingleSignOnExtension _x = _copy();
        _x.odataType = Util.nvl(odataType, "microsoft.graph.credentialSingleSignOnExtension");
        _x.extensionIdentifier = extensionIdentifier;
        return _x;
    }

    /**
     * <i>“Gets or sets the case-sensitive realm name for this profile.”</i>
     * 
     * @return property realm
     */
    @Property(name="realm")
    @JsonIgnore
    public Optional<String> getRealm() {
        return Optional.ofNullable(realm);
    }

    /**
     * Returns an immutable copy of {@code this} with just the {@code realm} field
     * changed. Field description below. The field name is also added to an internal
     * map of changed fields in the returned object so that when {@code this.patch()}
     * is called (if available)on the returned object only the changed fields are
     * submitted.
     * <p>
     * <i>“Gets or sets the case-sensitive realm name for this profile.”</i>
     * 
     * @param realm
     *            new value of {@code realm} field (as defined in service metadata)
     * @return immutable copy of {@code this} with just the {@code realm} field changed
     */
    public CredentialSingleSignOnExtension withRealm(String realm) {
        CredentialSingleSignOnExtension _x = _copy();
        _x.odataType = Util.nvl(odataType, "microsoft.graph.credentialSingleSignOnExtension");
        _x.realm = realm;
        return _x;
    }

    /**
     * <i>“Gets or sets the team ID of the app extension that performs SSO for the
     * specified URLs.”</i>
     * 
     * @return property teamIdentifier
     */
    @Property(name="teamIdentifier")
    @JsonIgnore
    public Optional<String> getTeamIdentifier() {
        return Optional.ofNullable(teamIdentifier);
    }

    /**
     * Returns an immutable copy of {@code this} with just the {@code teamIdentifier}
     * field changed. Field description below. The field name is also added to an
     * internal map of changed fields in the returned object so that when {@code this.
     * patch()} is called (if available)on the returned object only the changed fields
     * are submitted.
     * <p>
     * <i>“Gets or sets the team ID of the app extension that performs SSO for the
     * specified URLs.”</i>
     * 
     * @param teamIdentifier
     *            new value of {@code teamIdentifier} field (as defined in service metadata)
     * @return immutable copy of {@code this} with just the {@code teamIdentifier} field changed
     */
    public CredentialSingleSignOnExtension withTeamIdentifier(String teamIdentifier) {
        CredentialSingleSignOnExtension _x = _copy();
        _x.odataType = Util.nvl(odataType, "microsoft.graph.credentialSingleSignOnExtension");
        _x.teamIdentifier = teamIdentifier;
        return _x;
    }

    public CredentialSingleSignOnExtension withUnmappedField(String name, Object value) {
        CredentialSingleSignOnExtension _x = _copy();
        _x.setUnmappedField(name, value);
        return _x;
    }

    @JsonAnySetter
    private void setUnmappedField(String name, Object value) {
        if (unmappedFields == null) {
            unmappedFields = new UnmappedFieldsImpl();
        }
        unmappedFields.put(name, value);
    }

    @JsonAnyGetter
    private UnmappedFieldsImpl unmappedFields() {
        return unmappedFields == null ? UnmappedFieldsImpl.EMPTY : unmappedFields;
    }

    @Override
    public UnmappedFields getUnmappedFields() {
        return unmappedFields();
    }

    @Override
    public void postInject(boolean addKeysToContextPath) {
        // do nothing;
    }

    /**
     * Returns a builder which is used to create a new
     * instance of this class (given that this class is immutable).
     *
     * @return a new Builder for this class
     */
    // Suffix used on builder factory method to differentiate the method
    // from static builder methods on superclasses
    public static Builder builderCredentialSingleSignOnExtension() {
        return new Builder();
    }

    public static final class Builder {
        private List<KeyTypedValuePair> configurations;
        private String configurationsNextLink;
        private List<String> domains;
        private String domainsNextLink;
        private String extensionIdentifier;
        private String realm;
        private String teamIdentifier;
        private ChangedFields changedFields = ChangedFields.EMPTY;

        Builder() {
            // prevent instantiation
        }

        /**
         * <i>“Gets or sets a list of typed key-value pairs used to configure Credential-type
         * profiles. This collection can contain a maximum of 500 elements.”</i>
         * 
         * @param configurations
         *            value of {@code configurations} property (as defined in service metadata)
         * @return {@code this} (for method chaining)
         */
        public Builder configurations(List<KeyTypedValuePair> configurations) {
            this.configurations = configurations;
            this.changedFields = changedFields.add("configurations");
            return this;
        }

        /**
         * <i>“Gets or sets a list of typed key-value pairs used to configure Credential-type
         * profiles. This collection can contain a maximum of 500 elements.”</i>
         * 
         * @param configurations
         *            value of {@code configurations} property (as defined in service metadata)
         * @return {@code this} (for method chaining)
         */
        public Builder configurations(KeyTypedValuePair... configurations) {
            return configurations(Arrays.asList(configurations));
        }

        /**
         * <i>“Gets or sets a list of typed key-value pairs used to configure Credential-type
         * profiles. This collection can contain a maximum of 500 elements.”</i>
         * 
         * @param configurationsNextLink
         *            value of {@code configurations@nextLink} property (as defined in service metadata)
         * @return {@code this} (for method chaining)
         */
        public Builder configurationsNextLink(String configurationsNextLink) {
            this.configurationsNextLink = configurationsNextLink;
            this.changedFields = changedFields.add("configurations");
            return this;
        }

        /**
         * <i>“Gets or sets a list of hosts or domain names for which the app extension
         * performs SSO.”</i>
         * 
         * @param domains
         *            value of {@code domains} property (as defined in service metadata)
         * @return {@code this} (for method chaining)
         */
        public Builder domains(List<String> domains) {
            this.domains = domains;
            this.changedFields = changedFields.add("domains");
            return this;
        }

        /**
         * <i>“Gets or sets a list of hosts or domain names for which the app extension
         * performs SSO.”</i>
         * 
         * @param domains
         *            value of {@code domains} property (as defined in service metadata)
         * @return {@code this} (for method chaining)
         */
        public Builder domains(String... domains) {
            return domains(Arrays.asList(domains));
        }

        /**
         * <i>“Gets or sets a list of hosts or domain names for which the app extension
         * performs SSO.”</i>
         * 
         * @param domainsNextLink
         *            value of {@code domains@nextLink} property (as defined in service metadata)
         * @return {@code this} (for method chaining)
         */
        public Builder domainsNextLink(String domainsNextLink) {
            this.domainsNextLink = domainsNextLink;
            this.changedFields = changedFields.add("domains");
            return this;
        }

        /**
         * <i>“Gets or sets the bundle ID of the app extension that performs SSO for the
         * specified URLs.”</i>
         * 
         * @param extensionIdentifier
         *            value of {@code extensionIdentifier} property (as defined in service metadata)
         * @return {@code this} (for method chaining)
         */
        public Builder extensionIdentifier(String extensionIdentifier) {
            this.extensionIdentifier = extensionIdentifier;
            this.changedFields = changedFields.add("extensionIdentifier");
            return this;
        }

        /**
         * <i>“Gets or sets the case-sensitive realm name for this profile.”</i>
         * 
         * @param realm
         *            value of {@code realm} property (as defined in service metadata)
         * @return {@code this} (for method chaining)
         */
        public Builder realm(String realm) {
            this.realm = realm;
            this.changedFields = changedFields.add("realm");
            return this;
        }

        /**
         * <i>“Gets or sets the team ID of the app extension that performs SSO for the
         * specified URLs.”</i>
         * 
         * @param teamIdentifier
         *            value of {@code teamIdentifier} property (as defined in service metadata)
         * @return {@code this} (for method chaining)
         */
        public Builder teamIdentifier(String teamIdentifier) {
            this.teamIdentifier = teamIdentifier;
            this.changedFields = changedFields.add("teamIdentifier");
            return this;
        }

        public CredentialSingleSignOnExtension build() {
            CredentialSingleSignOnExtension _x = new CredentialSingleSignOnExtension();
            _x.contextPath = null;
            _x.unmappedFields = new UnmappedFieldsImpl();
            _x.odataType = "microsoft.graph.credentialSingleSignOnExtension";
            _x.configurations = configurations;
            _x.configurationsNextLink = configurationsNextLink;
            _x.domains = domains;
            _x.domainsNextLink = domainsNextLink;
            _x.extensionIdentifier = extensionIdentifier;
            _x.realm = realm;
            _x.teamIdentifier = teamIdentifier;
            return _x;
        }
    }

    private CredentialSingleSignOnExtension _copy() {
        CredentialSingleSignOnExtension _x = new CredentialSingleSignOnExtension();
        _x.contextPath = contextPath;
        _x.unmappedFields = unmappedFields.copy();
        _x.odataType = odataType;
        _x.configurations = configurations;
        _x.domains = domains;
        _x.extensionIdentifier = extensionIdentifier;
        _x.realm = realm;
        _x.teamIdentifier = teamIdentifier;
        return _x;
    }

    @Override
    public String toString() {
        StringBuilder b = new StringBuilder();
        b.append("CredentialSingleSignOnExtension[");
        b.append("configurations=");
        b.append(this.configurations);
        b.append(", ");
        b.append("domains=");
        b.append(this.domains);
        b.append(", ");
        b.append("extensionIdentifier=");
        b.append(this.extensionIdentifier);
        b.append(", ");
        b.append("realm=");
        b.append(this.realm);
        b.append(", ");
        b.append("teamIdentifier=");
        b.append(this.teamIdentifier);
        b.append("]");
        b.append(",unmappedFields=");
        b.append(unmappedFields);
        b.append(",odataType=");
        b.append(odataType);
        return b.toString();
    }

}
